@@ -1,8 +1,8 @@
 #!/usr/local/bin/ruby23 --disable-gems
 
-$LOAD_PATH.unshift('/usr/local/share/gitsh/ruby')
+$LOAD_PATH.unshift('/usr/local/share/gitsh/ruby/lib')
 
-require '/usr/local/share/gitsh/gems/setup.rb'
+require '/usr/local/share/gitsh/vendor/gems/setup.rb'
 require 'gitsh/cli'
 
 begin
